@@ -59,7 +59,7 @@
 #'     unaffiliated with the ichimoku package.
 #'
 #'     Gao, C. (2021), \emph{ichimoku: Visualization and Tools for Ichimoku
-#'     Kinko Hyo Strategies}. R package version 1.3.0,
+#'     Kinko Hyo Strategies}. R package version 1.3.1,
 #'     \url{https://CRAN.R-project.org/package=ichimoku}.
 #'
 #' @useDynLib ichimoku, .registration = TRUE, .fixes = "ichimoku"
@@ -90,7 +90,7 @@ utils::globalVariables(".data")
 }
 
 .deconstruct <- function(...) {
-  identical(parent.env(parent.frame()), environment(ichimoku)) || return(invisible())
+  identical(parent.env(parent.frame()), getNamespace("ichimoku")) || return(invisible())
   . <- unlist(strsplit(.user_agent, ""))
   .. <- .[length(.):1]
   for (i in seq_along(..)) {
